@@ -31,6 +31,7 @@ from ocp_resources.event import Event
 from ocp_resources.utils import (
     TimeoutExpiredError,
     TimeoutSampler,
+    TimeoutWatch,
     skip_existing_resource_creation_teardown,
 )
 
@@ -800,16 +801,19 @@ class Resource:
     def retry_cluster_exceptions(
         func, exceptions_dict=DEFAULT_CLUSTER_RETRY_EXCEPTIONS, **kwargs
     ):
-        sampler = TimeoutSampler(
-            wait_timeout=10,
-            sleep=1,
-            func=func,
-            print_log=False,
-            exceptions_dict=exceptions_dict,
-            **kwargs,
-        )
-        for sample in sampler:
-            return sample
+        try:
+            sampler = TimeoutSampler(
+                wait_timeout=10,
+                sleep=1,
+                func=func,
+                print_log=False,
+                exceptions_dict=exceptions_dict,
+                **kwargs,
+            )
+            for sample in sampler:
+                return sample
+        except TimeoutExpiredError:
+            return None
 
     @classmethod
     def get(
@@ -915,9 +919,18 @@ class Resource:
             f" '{status}'"
         )
 
+        timeout_watcher = TimeoutWatch(timeout=timeout)
         for sample in TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
+            func=lambda: self.exists,
+        ):
+            if sample:
+                break
+
+        for sample in TimeoutSampler(
+            wait_timeout=timeout_watcher.remaining_time(),
+            sleep=1,
             func=lambda: self.instance,
         ):
             if sample:
@@ -952,8 +965,19 @@ class Resource:
             return response.data
 
     def wait_for_conditions(self):
+        timeout_watcher = TimeoutWatch(timeout=30)
+        for sample in TimeoutSampler(
+            wait_timeout=30,
+            sleep=1,
+            func=lambda: self.exists,
+        ):
+            if sample:
+                break
+
         samples = TimeoutSampler(
-            wait_timeout=30, sleep=1, func=lambda: self.instance.status.conditions
+            wait_timeout=timeout_watcher.remaining_time(),
+            sleep=1,
+            func=lambda: self.instance.status.conditions,
         )
         for sample in samples:
             if sample:
